@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2018 Aurimas Cernius
+ * Copyright (C) 2010-2020 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -184,7 +184,6 @@ namespace gnote {
     }
 
     make_app_actions();
-    make_app_menu();
     if(is_background()) {
       // do not exit when all windows are closed
       hold();
@@ -230,17 +229,6 @@ namespace gnote {
   }
 
 
-  void Gnote::on_quit_gnote_action(const Glib::VariantBase&)
-  {
-    std::vector<Gtk::Window*> windows = Gtk::Window::list_toplevels();
-    FOREACH(Gtk::Window *window, windows) {
-      window->close();
-    }
-    if(is_background()) {
-      release();
-    }
-  }
-
   void Gnote::on_preferences_response(int /*res*/)
   {
     delete m_prefsdlg;
@@ -298,7 +286,7 @@ namespace gnote {
     about.set_program_name("Gnote");
     about.set_version(VERSION);
     about.set_logo(IconManager::obj().get_icon(IconManager::GNOTE, 48));
-    about.set_copyright(_("Copyright \xc2\xa9 2010-2018 Aurimas Cernius\n"
+    about.set_copyright(_("Copyright \xc2\xa9 2010-2020 Aurimas Cernius\n"
                           "Copyright \xc2\xa9 2009-2011 Debarshi Ray\n"
                           "Copyright \xc2\xa9 2009 Hubert Figuiere\n"
                           "Copyright \xc2\xa9 2004-2009 the Tomboy original authors."));
@@ -449,7 +437,6 @@ namespace gnote {
     am.get_app_action("help-contents")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_show_help_action));
     am.get_app_action("help-shortcuts")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_show_help_shortcust_action));
     am.get_app_action("about")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_show_about_action));
-    am.get_app_action("quit")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_quit_gnote_action));
 
     add_app_actions(static_cast<ActionManager &>(am).get_app_actions());
   }
@@ -503,12 +490,6 @@ namespace gnote {
   }
 
 
-  void Gnote::make_app_menu()
-  {
-    set_app_menu(static_cast<ActionManager &>(IActionManager::obj()).get_app_menu());
-  }
-
-
   GnoteCommandLine::GnoteCommandLine()
     : m_context(g_option_context_new("Foobar"))
     , m_use_panel(false)
