@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2014,2017 Aurimas Cernius
+ * Copyright (C) 2011-2014,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -62,15 +62,15 @@ Glib::ustring NoteBase::url_from_path(const Glib::ustring & filepath)
   return "note://gnote/" + sharp::file_basename(filepath);
 }
 
-void NoteBase::parse_tags(const xmlNodePtr tagnodes, std::list<Glib::ustring> & tags)
+std::vector<Glib::ustring> NoteBase::parse_tags(const xmlNodePtr tagnodes)
 {
+  std::vector<Glib::ustring> tags;
   sharp::XmlNodeSet nodes = sharp::xml_node_xpath_find(tagnodes, "//*");
 
   if(nodes.empty()) {
-    return;
+    return tags;
   }
-  for(sharp::XmlNodeSet::const_iterator iter = nodes.begin(); iter != nodes.end(); ++iter) {
-    const xmlNodePtr node = *iter;
+  for(auto & node : nodes) {
     if(xmlStrEqual(node->name, (const xmlChar*)"tag") && (node->type == XML_ELEMENT_NODE)) {
       xmlChar * content = xmlNodeGetContent(node);
       if(content) {
@@ -80,6 +80,8 @@ void NoteBase::parse_tags(const xmlNodePtr tagnodes, std::list<Glib::ustring> &
       }
     }
   }
+
+  return tags;
 }
 
 
@@ -138,7 +140,7 @@ void NoteBase::process_rename_link_update(const Glib::ustring & old_title)
   const NoteBase::Ptr self = shared_from_this();
 
   if(!linking_notes.empty()) {
-    FOREACH(NoteBase::Ptr & note, linking_notes) {
+    for(NoteBase::Ptr & note : linking_notes) {
       note->rename_links(old_title, self);
       signal_renamed(shared_from_this(), old_title);
       queue_save(CONTENT_CHANGED);
@@ -214,8 +216,9 @@ void NoteBase::handle_link_rename(const Glib::ustring &, const Ptr &, bool)
 void NoteBase::delete_note()
 {
   // Remove the note from all the tags
-  for(NoteData::TagMap::const_iterator iter = data_synchronizer().data().tags().begin();
-      iter != data_synchronizer().data().tags().end(); ++iter) {
+  // remove_tag modifies map, so always iterate from start
+  NoteData::TagMap & thetags(data_synchronizer().data().tags());
+  for(NoteData::TagMap::const_iterator iter = thetags.begin(); iter != thetags.end(); iter = thetags.begin()) {
     remove_tag(iter->second);
   }
 }
@@ -307,7 +310,7 @@ void NoteBase::load_foreign_note_xml(const Glib::ustring & foreignNoteXml, Chang
 
   // Remove tags now, since a note with no tags has
   // no "tags" element in the XML
-  std::list<Tag::Ptr> new_tags;
+  std::vector<Tag::Ptr> new_tags;
   Glib::ustring name;
 
   while(xml.read()) {
@@ -332,9 +335,8 @@ void NoteBase::load_foreign_note_xml(const Glib::ustring & foreignNoteXml, Chang
       else if(name == "tags") {
         xmlDocPtr doc2 = xmlParseDoc((const xmlChar*)xml.read_outer_xml().c_str());
         if(doc2) {
-          std::list<Glib::ustring> tag_strings;
-          parse_tags(doc2->children, tag_strings);
-          FOREACH(Glib::ustring & tag_str, tag_strings) {
+          std::vector<Glib::ustring> tag_strings = parse_tags(doc2->children);
+          for(const Glib::ustring & tag_str : tag_strings) {
             Tag::Ptr tag = ITagManager::obj().get_or_create_tag(tag_str);
             new_tags.push_back(tag);
           }
@@ -352,15 +354,14 @@ void NoteBase::load_foreign_note_xml(const Glib::ustring & foreignNoteXml, Chang
 
   xml.close();
 
-  std::list<Tag::Ptr> tag_list;
-  get_tags(tag_list);
+  std::vector<Tag::Ptr> tag_list = get_tags();
 
-  FOREACH(Tag::Ptr & iter, tag_list) {
+  for(Tag::Ptr & iter : tag_list) {
     if(std::find(new_tags.begin(), new_tags.end(), iter) == new_tags.end()) {
       remove_tag(iter);
     }
   }
-  FOREACH(Tag::Ptr & iter, new_tags) {
+  for(Tag::Ptr & iter : new_tags) {
     add_tag(iter);
   }
     
@@ -368,9 +369,9 @@ void NoteBase::load_foreign_note_xml(const Glib::ustring & foreignNoteXml, Chang
   queue_save(changeType);
 }
 
-void NoteBase::get_tags(std::list<Tag::Ptr> & l) const
+std::vector<Tag::Ptr> NoteBase::get_tags() const
 {
-  sharp::map_get_values(data_synchronizer().data().tags(), l);
+  return sharp::map_get_values(data_synchronizer().data().tags());
 }
 
 const NoteData & NoteBase::data() const
@@ -492,9 +493,8 @@ void NoteArchiver::_read(sharp::XmlReader & xml, NoteData & data, Glib::ustring
         xmlDocPtr doc2 = xmlParseDoc((const xmlChar*)xml.read_outer_xml().c_str());
 
         if(doc2) {
-          std::list<Glib::ustring> tag_strings;
-          NoteBase::parse_tags(doc2->children, tag_strings);
-          FOREACH(Glib::ustring & tag_str, tag_strings) {
+          std::vector<Glib::ustring> tag_strings = NoteBase::parse_tags(doc2->children);
+          for(const Glib::ustring & tag_str : tag_strings) {
             Tag::Ptr tag = ITagManager::obj().get_or_create_tag(tag_str);
             data.tags()[tag->normalized_name()] = tag;
           }
